CubicCurveTo class

A Cubic Bezier Curve to x y.

Constructors

CubicCurveTo(num controlPoint1X, num controlPoint1Y, num controlPoint2X, num controlPoint2Y, num x, num y)

Properties

controlPoint1X ↔ num
getter/setter pair
controlPoint1Y ↔ num
getter/setter pair
controlPoint2X ↔ num
getter/setter pair
controlPoint2Y ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ num
getter/setter pair
y ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited