DynamicDimension class

Implemented types
Available extensions

Constructors

DynamicDimension(PDimension computer(PDimension? size))

Properties

area → num
The area of this dimension.
no setteroverride
aspectRation → double
The aspect ration of this dimension (width / height).
no setteroverride
center → Point
The center point of this dimension.
no setteroverride
className → String
no setteroverride
computer → PDimension Function(PDimension? size)
final
dimension → PDimension
The PDimension of this instance.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
height → num
The dimension height.
no setteroverride
isZeroDimension → bool
Returns true if the area of this dimension is zero.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ PDimension?
getter/setter pair
width → num
The dimension width.
no setteroverride

Methods

compute() → PDimension
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → PDimension
Returns a resolved version of this instance.
override
setHeight(num height) → PDimension
override
setWidth(num width) → PDimension
override
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toPRectangle({num x = 0, num y = 0}) → PRectangle
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override