DynamicPosition class

Implemented types
Available extensions

Constructors

DynamicPosition(Point computer(Point p))

Properties

className → String
no setteroverride
computer → Point Function(Point p)
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translate ↔ Point
getter/setter pair
x → num
The resolved X coordinate.
no setteroverride
y → num
The resolved Y coordinate.
no setteroverride

Methods

compute() → Position
Computes the current value of this instance, calling computer.
decrement(WithXY p) → Position
Increments the X,Y coordinates by p.
override
increment(WithXY p) → Position
Increments the X,Y coordinates by p.
override
incrementX(num n) → Position
Increments the X coordinate by n
override
incrementXY(num nX, num nY) → Position
Increments the X,Y coordinates by nX and nY.
override
incrementY(num n) → Position
Increments the Y coordinate by n
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → Position
Returns the computed version of this instance. See compute.
override
setX(num x) → Position
Sets the X coordinate.
override
setXY(num x, num y) → Position
Sets the X and Y coordinate.
override
setY(num y) → Position
Sets the Y coordinate.
override
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toPoint() → Point
Returns this position as a Point.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override