GLine class

Inheritance
Available extensions

Constructors

GLine(int x1, int y1, int x2, int y2, {int size = 1, PColor? color})
GLine.fromJson(Map<String, dynamic> json)
factory

Properties

className → String
no setteroverride
color ↔ PColor?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeBoundingBox → PRectangle
no setteroverride
shapeName → String
no setteroverride
size ↔ int
getter/setter pair
x1 ↔ int
getter/setter pair
x2 ↔ int
getter/setter pair
y1 ↔ int
getter/setter pair
y2 ↔ int
getter/setter pair

Methods

containsPoint(Point p) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PCanvas pCanvas, [GraphicContext? graphicContext]) → void
override
resolveGraphicContext([GraphicContext? parentContext]) → GraphicContext
override
scaled(double scale) → GLine
Scaled version of this GShape.
override
selectShapesAtPoint(Point p, {bool recursive = false}) → List<GShape>
inherited
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String
inherited
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toString() → String
A string representation of this object.
inherited
translate(Point p) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited