GPanel class

A panel shape that can have sub-shapes (elements).

Inheritance
Available extensions

Constructors

GPanel(int x, int y, int width, int height, List<GShape> elements, {PColor? backgroundColor})
GPanel.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ PColor?
getter/setter pair
className → String
no setteroverride
elements ↔ List<GShape>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeBoundingBox → PRectangle
no setteroverride
shapeName → String
no setteroverride
width ↔ int
getter/setter pair
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

containsPoint(Point p) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PCanvas pCanvas, [GraphicContext? graphicContext]) → void
override
resolveGraphicContext([GraphicContext? parentContext]) → GraphicContext
override
scaled(double scale) → GPanel
Scaled version of this GShape.
override
selectShapesAtPoint(Point p, {bool recursive = false}) → List<GShape>
override
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String
inherited
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toString() → String
A string representation of this object.
inherited
translate(Point p) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited