GShape class abstract

Implemented types
Available extensions

Constructors

GShape()

Properties

className → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeBoundingBox → PRectangle
no setter
shapeName → String
no setter

Methods

containsPoint(Point p) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PCanvas pCanvas, [GraphicContext? graphicContext]) → void
resolveGraphicContext([GraphicContext? parentContext]) → GraphicContext
scaled(double scale) → GShape
Scaled version of this GShape.
selectShapesAtPoint(Point p, {bool recursive = false}) → List<GShape>
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toString() → String
A string representation of this object.
inherited
translate(Point p) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(Map<String, dynamic>? json) → GShape?
listFrom(List<Map<String, dynamic>>? jsonList) → List<GShape>