Graphic class

A graphic built by simple shapes (GShape).

Inheritance
Available extensions

Constructors

Graphic(int width, int height, List<GShape> shapes)
Graphic.fromJson(Map<String, dynamic> json)
factory

Properties

className → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeBoundingBox → PRectangle
no setteroverride
shapeName → String
no setteroverride
shapes ↔ List<GShape>
getter/setter pair
width ↔ int
getter/setter pair

Methods

containsPoint(Point p) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PCanvas pCanvas, [GraphicContext? graphicContext]) → void
override
resolveGraphicContext([GraphicContext? parentContext]) → GraphicContext
inherited
scaled(double scale) → Graphic
Scaled version of this GShape.
override
selectShapesAtPoint(Point p, {bool recursive = false}) → List<GShape>
override
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String
inherited
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toString() → String
A string representation of this object.
inherited
translate(Point p) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited