PCanvasImage class abstract

Base class for PCanvas compatible images. See PCanvas.createCanvasImage.

Constructors

PCanvasImage()

Properties

aspectRatio → double
The aspect ratio of the image (width / height).
no setter
dimension → PDimension
The dimension of the image (width x height).
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the image. See isLoaded.
no setter
id → Object
The ID of the image int the PCanvas instance.
no setter
info → Map<String, Object?>
Information of the image.
no setter
isLoaded → bool
Returns true if this image is loaded.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String
The source of the image.
no setter
type → String
The implementation type.
no setter
width → int
The width of the image. See isLoaded.
no setter

Methods

load() → FutureOr<bool>
Loads the image.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited