PCanvasPixelsRGBA class

PCanvasPixels in RGBA format.

Inheritance

Constructors

PCanvasPixelsRGBA.blank(int width, int height)
PCanvasPixelsRGBA.fromBytes(int width, int height, List<int> bytes)
PCanvasPixelsRGBA.fromPixels(int width, int height, Uint32List pixels)

Properties

format → String
The pixel format.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
height → int
Height of the pixels image.
finalinherited
length → int
Length of pixels.
no setterinherited
lengthInBytes → int
Length of pixels in bytes.
no setterinherited
pixels → Uint32List
Pixels are encoded into 4-byte Uint32 integers. See format.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the pixels image.
finalinherited

Methods

copyRect(int x, int y, int width, int height) → PCanvasPixels?
inherited
copyRectangle(PRectangle r) → PCanvasPixels?
inherited
createBlank(int width, int height) → PCanvasPixelsRGBA
Creates a blank PCanvasPixels instance with the same format of this one.
override
formatColor(PColor color) → int
Formats color to this instance format.
override
isSameFormat(PCanvasPixels other) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseColor(int pixel) → PColorRGB
Parse pixel to PColor;
override
pixel(int x, int y) → int
Returns a pixel at (x,y) in the format 4-byte Uint32 integer in format.
inherited
pixelA(int x, int y) → int
Returns the Alpha channel of pixel at (x,y).
override
pixelB(int x, int y) → int
Returns the Blue channel of pixel at (x,y).
override
pixelColor(int x, int y) → PColorRGB
Returns a pixel at (x,y) as PColor.
inherited
pixelG(int x, int y) → int
Returns the Green channel of pixel at (x,y).
override
pixelIndex(int x, int y) → int
Index of a pixel (x,y) at pixels.
inherited
pixelR(int x, int y) → int
Returns the Red channel of pixel at (x,y).
override
putPixels(PCanvasPixels src, num dstX, num dstY) → void
inherited
setPixel(int x, int y, int p) → void
Sets a pixels at (x,y) with value p.
inherited
setPixelFrom(PCanvasPixels src, int srcX, int srcY, int dstX, int dstY) → void
Sets a pixels at (dstX,dstY) with value from src at (srcX,srcY).
inherited
setPixelsColumnFrom(PCanvasPixels src, int srcX, int srcY, int dstX, int dstY, int height) → void
inherited
setPixelsLineFrom(PCanvasPixels src, int srcX, int srcY, int dstX, int dstY, int width) → void
inherited
setPixelsRectFrom(PCanvasPixels src, int srcX, int srcY, int dstX, int dstY, int width, int height) → void
inherited
toDataUrl() → FutureOr<String>
inherited
toPCanvas({PCanvasPainter? painter}) → PCanvas
inherited
toPCanvasPixelsABGR() → PCanvasPixelsABGR
override
toPCanvasPixelsARGB() → PCanvasPixelsARGB
override
toPCanvasPixelsRGBA() → PCanvasPixelsRGBA
override
toPNG() → FutureOr<Uint8List>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited