PFont class

A PCanvas font.

Available extensions

Constructors

PFont(String family, num size, {bool bold = false, bool italic = false, String? familyFallback})

Properties

bold → bool
If true the font is bold.
final
family → String
The family of the font.
final
familyFallback → String?
The family fallback.
final
hashCode → int
The hash code for this object.
no setteroverride
italic → bool
If true the font is italic.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num
The size of the font.
final

Methods

equals(PFont other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCSS({num pixelRatio = 1}) → String
Returns this font properties in CSS.
toString() → String
A string representation of this object.
override
toTextStyle({PColor? color, num pixelRatio = 1}) → TextStyle

Available on PFont, provided by the PFontExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → PFont
This dummy instance shouldn't be used in paint operations.
final