PStyle class

Implemented types
Available extensions

Constructors

PStyle({PColor? color, int? size})
const
PStyle.fromJson(Map<String, dynamic> j)
factory

Properties

asPaintFill → Paint

Available on PStyle, provided by the PStyleExtension extension

no setter
className → String
no setteroverride
color → PColor?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
final

Methods

equals(PStyle other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toPaintStroke({num pixelRatio = 1}) → Paint

Available on PStyle, provided by the PStyleExtension extension

toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

none → const PStyle