PTextMetric class

A PCanvas text metric.

Inheritance
Available extensions

Constructors

PTextMetric(num width, num height, [num? actualWidth, num? actualHeight, num? y])
const

Properties

actualHeight → num
The actual height of the text.
final
actualWidth → num
The actual width of the text.
final
area → num
The area of this dimension.
no setterinherited
aspectRation → double
The aspect ration of this dimension (width / height).
no setterinherited
center → Point
The center point of this dimension.
no setterinherited
className → String
no setterinherited
dimension → PTextMetric
The PDimension of this instance.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
height → num
The dimension height.
finalinherited
inCompliance → bool
Returns true if actualWidth == width AND actualHeight == height.
no setter
isZeroDimension → bool
Returns true if the area of this dimension is zero.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num
The dimension width.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → PDimension
Returns a resolved version of this instance.
inherited
setHeight(num height) → PDimension
inherited
setWidth(num width) → PDimension
inherited
toJson() → Map<String, dynamic>
inherited
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toPRectangle({num x = 0, num y = 0}) → PRectangle
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override