PcanvasTransform class

PCanvas transformation.

Constructors

PcanvasTransform({num translateX = 0, num translateY = 0})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isZeroTransformation → bool
no setter
isZeroTranslation → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translate → Point
no setter
translateX → num
final
translateY → num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
point(Point p) → Point
toString() → String
A string representation of this object.
override
x(num x) → num
xD(num x) → double
y(num y) → num
yD(num y) → double

Operators

operator +(PcanvasTransform other) → PcanvasTransform
operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const PcanvasTransform