Point class

A PCanvas point.

Implemented types
Available extensions

Constructors

Point(num x, num y)
const
Point.fromJson(Map<String, dynamic> j)
factory

Properties

className → String
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isZero → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → num
The X coordinate.
final
y → num
The Y coordinate.
final

Methods

decrement(WithXY p) → Point
Increments the X,Y coordinates by p.
override
increment(WithXY p) → Point
Increments the X,Y coordinates by p.
override
incrementX(num n) → Point
Increments the X coordinate by n
override
incrementXY(num nX, num nY) → Point
Increments the X,Y coordinates by nX and nY.
override
incrementY(num n) → Point
Increments the Y coordinate by n
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → Point
A resolved version of this instance. See DynamicPoint.
override
scale(num scaleX, num scaleY) → Point
setX(num x) → Point
Sets the X coordinate.
override
setXY(num x, num y) → Point
Sets the X and Y coordinate.
override
setY(num y) → Point
Sets the Y coordinate.
override
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toPoint() → Point
Returns this position as a Point.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

pZero → Point
final