Position class abstract

Implemented types
Available extensions

Constructors

Position.fromJson(Map<String, dynamic> j)
factory

Properties

className → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → num
The resolved X coordinate.
no setteroverride
y → num
The resolved Y coordinate.
no setteroverride

Methods

decrement(WithXY p) → Position
Increments the X,Y coordinates by p.
increment(WithXY p) → Position
Increments the X,Y coordinates by p.
incrementX(num n) → Position
Increments the X coordinate by n
incrementXY(num nX, num nY) → Position
Increments the X,Y coordinates by nX and nY.
incrementY(num n) → Position
Increments the Y coordinate by n
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → Position
A resolved version of this instance. See DynamicPoint.
setX(num x) → Position
Sets the X coordinate.
setXY(num x, num y) → Position
Sets the X and Y coordinate.
setY(num y) → Position
Sets the Y coordinate.
toJson() → Map<String, dynamic>
override
toJsonEncoded({bool pretty = false}) → String

Available on WithJson, provided by the WithJsonExtension extension

toPoint() → Point
Returns this position as a Point.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

resolvePosition(Position? pos, num? x, num? y, {PCanvasElement? element}) → Position