WithDimension class abstract mixin

Implementers

Constructors

WithDimension()

Properties

area → num
The area of this dimension.
no setter
aspectRation → double
The aspect ration of this dimension (width / height).
no setter
center → Point
The center point of this dimension.
no setter
dimension → PDimension
The PDimension of this instance.
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
The dimension height.
no setter
isZeroDimension → bool
Returns true if the area of this dimension is zero.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num
The dimension width.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited